#ifdef GL_ES                                
precision lowp float;                        
#endif                                        

uniform sampler2D u_texture;

uniform vec2 texture_size;

uniform float light_factor;
uniform float light_offset;
uniform float light_size;
uniform vec3 light_color;

varying vec4 v_fragmentColor;                
varying vec2 v_texCoord;

const float SQRT_2 = 1.414;


void main()                                    
{
    vec4 texColor = texture2D(u_texture, v_texCoord);

    // 流光
    // line (x+y-offset=0) offset:[0, 2] (2->0)
    //     |y
    //     |
    // ____|0___ 1___2____x
    //     |    |
    //     |____|*
    float k = (texture_size[0] / texture_size[1]);
    float distance = abs(k * v_texCoord[0] + v_texCoord[1] - light_offset) / SQRT_2;
    
    // linear gradient
    // (1/size)x + y = 1
    distance = 1.0 - (1.0 / light_size) * distance;
    distance = max(distance, 0.0);

    vec4 sample = vec4(0.0,0.0,0.0,0.0);
    sample.rgb = light_color * distance;
    sample.a = distance;

    // blend additive
    float alpha = sample[3] * texColor[3];
    texColor[0] = texColor[0] + sample[0] * alpha * light_factor;
    texColor[1] = texColor[1] + sample[1] * alpha * light_factor;
    texColor[2] = texColor[2] + sample[2] * alpha * light_factor;
    
    gl_FragColor = v_fragmentColor * texColor;
}
